@@ -57,18 +57,20 @@ function(x=NULL,
     order.by <- order.by[indx]
   }
 
-  tz <- Sys.getenv('TZ')
-  on.exit( Sys.setenv(TZ=tz) )
-  Sys.setenv(TZ='GMT')
+  #tz <- Sys.getenv('TZ')
+  #on.exit( Sys.setenv(TZ=tz) )
+  #Sys.setenv(TZ='GMT')
 
   if(!is.null(x) || length(x) != 0 ) {
     x <- as.matrix(x)
   } else x <- numeric(0)
 
+  index <- as.numeric(as.POSIXct(order.by))
   x <- structure(.Data=x,
-            index=as.numeric(as.POSIXct(order.by)),
+            index=index,
             class=c('xts','zoo'),
             .indexCLASS=orderBy,
+            .indexTZ=Sys.getenv("TZ"),  # TZ in force on creation
             ...)
   if(!is.null(attributes(x)$dimnames[[1]]))
     # this is very slow if user adds rownames, but maybe that is deserved :)
@@ -94,19 +96,19 @@ function(x=NULL, index, .indexCLASS=c("POSIXt","POSIXct"),  check=TRUE, unique=F
 
   structure(.Data=x,
             index=index,
-            .indexCLASS=.indexCLASS,
+            .indexCLASS=.indexCLASS,.indexTZ=Sys.getenv("TZ"),
             class=c('xts','zoo'), ...)
 }
 
 `reclass` <-
 function(x, match.to, error=FALSE, ...) {
   if(!missing(match.to) && is.xts(match.to)) {
-    if(NROW(x) != length(index(match.to)))
+    if(NROW(x) != length(.index(match.to)))
       if(error) {
         stop('incompatible match.to attibutes')
       } else return(x)
 
-    if(!is.xts(x)) x <- xts(coredata(x),index(match.to))
+    if(!is.xts(x)) x <- .xts(coredata(x),.index(match.to), .indexCLASS=indexClass(match.to))
     CLASS(x) <- CLASS(match.to)
     xtsAttributes(x) <- xtsAttributes(match.to)
   }
